from setuptools import setup, find_packages

setup(
    name="django-custom",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[
        "django>=3.0",
    ],
    entry_points={
    "console_scripts": [
        "customstartapp = django_custom_startapp.management.commands.customstartapp:Command",
    ],
},
    author="Momo",
    author_email="omomo9414@gmail.com",
    description="A Django package to create apps with custom structure (urls.py, views/ and models/ directories)",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Framework :: Django",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)